@@ -239,15 +239,27 @@ class Microservices(BaseClass, ABC):
         # Parametros solicitados
         paramsConf = []
 
+        # Recuperar el rootSpan
+        rootSpan = msg['metadata']['span'] if 'span' in msg['metadata'] else None
+
         # Validar si es un smoktest
         if 'smoketest' in list(data):
+            span = self.___Tracer.start_span(
+                operation_name='smoketest', child_of=rootSpan)
+
+            span.set_tag(ext_tags.HTTP_METHOD, msg['metadata']['method'])
+
             # Ejecutar la funcion del smoketest
             if self.smoketest():
                 # Todo esta bien
-                self.__response(data, 0, True, msg.get('uuid', None))
+                self.__response(msg, 0, True, msg.get('uuid', None), span=span)
             else:
                 # Algo salio mal
-                self.__response(data, -1, True, msg.get('uuid', None))
+                self.__response(
+                    msg, -1, True, msg.get('uuid', None), span=span)
+
+            span.finish()
+            return
 
         # Solo actualizar los datos si e el servicio original
         if self.__TOPIC__ == msg['metadata']['callback']:
@@ -315,13 +327,16 @@ class Microservices(BaseClass, ABC):
         except Exception as e:
             self.logs.error(e)
 
-        rootSpan = msg['metadata']['span'] if 'span' in msg['metadata'] else None
         if rootSpan is not None:
             rootSpan = self.___Tracer.extract(Format.TEXT_MAP, rootSpan)
+
         span = self.___Tracer.start_span(operation_name=getattr(
             mth, '__FUNC_NAME__'), child_of=rootSpan)
+
         span.set_tag(ext_tags.HTTP_METHOD, msg['metadata']['method'])
 
+        RESP = {}
+
         # Enviar el mensaje al que procesa [Worker, Fork]
         try:
             # Configuracion de los forks
@@ -336,34 +351,38 @@ class Microservices(BaseClass, ABC):
 
             # ejecutar el proceso
             RESP = self.__APP.process(span, msg, mth, paramsConf)
+
             # Ruta [SOLO NATST]
             id_route_nats = getItemBy('response.uuid', RESP)
+
             # Enviar la respuesta
             self.__response(
                 RESP.get('response', {}),
                 RESP.get('errorCode'),
                 span=span,
                 nats_route=id_route_nats,
+                errorResp=RESP.get('errorWorker', None),
             )
         except ErrorMs as error:
             span.set_tag(ext_tags.ERROR, True)
             span.log_kv({'event': 'error', 'error.code': error.errorCode, 'error.message': self.___getErrorId(
                 error.errorCode), 'error.stack': traceback.format_exc()})
             self.logs.error(self.___getErrorId(error.errorCode))
-            self.__response(msg, error.errorCode, span=span,
-                            nats_route=msg.get('uuid', None))  # Enviar el error
+            self.__response(msg, error.errorCode, span=span, nats_route=msg.get(
+                'uuid', None), errorResp=RESP.get('errorWorker', None),)  # Enviar el error
+
         except Exception as e:
             span.set_tag(ext_tags.ERROR, True)
             span.log_kv({'event': 'error', 'error.message': str(
                 e), 'error.stack': traceback.format_exc()})
             self.logs.error(e)
             # Enviar el error
-            self.__response(msg, -99, span=span,
-                            nats_route=msg.get('uuid', None))
+            self.__response(msg, -99, span=span, nats_route=msg.get('uuid',
+                                                                    None), errorResp=RESP.get('errorWorker', None),)
 
         span.finish()
 
-    def __response(self, data, errorCode, isSmokeTest=False, nats_route=None, span=None):
+    def __response(self, data, errorCode, isSmokeTest=False, nats_route=None, span=None, errorResp=None):
         """
             Metodo para enviar la respuesta a kafka
         """
@@ -376,6 +395,10 @@ class Microservices(BaseClass, ABC):
         # Topico de respuesta
         TOPIC_RESP = None
 
+        # Comprobar si contiene un error heredado
+        if not errorResp is None:
+            errorCode = errorResp.get('errorCode', -99)  # Error generico
+
         # Validar si ocurrio un error
         if errorCode < 0:
             # Estructura del mensaje de error
@@ -385,7 +408,8 @@ class Microservices(BaseClass, ABC):
                         "hostname": self.__HOSTNAME,
                         "code": errorCode,
                         "errorCode": errorCode,
-                        "userMessage": self.___getErrorId(errorCode)
+                        # Regresar el mensaje que se proporciono desde el worker que se consumio
+                        "userMessage": self.___getErrorId(errorCode) if errorResp is None else errorResp.get('userMessage')
                     }
                 },
                 "meta": {
@@ -552,20 +576,24 @@ class Microservices(BaseClass, ABC):
         # Revisar si es un smoketest
         if isSmokeTest:
             # respuesta generica
-            Resp.set('response', {
-                "data": {
-                    "response": {
-                        "code": errorCode,
-                        "framework": version,
-                        "hostname": self.__HOSTNAME,
-                        "userMessage": "Smoke test"
+            Resp.update(
+                {
+                    'response': {
+                        "data": {
+                            "response": {
+                                "code": errorCode,
+                                "framework": version,
+                                "hostname": self.__HOSTNAME,
+                                "userMessage": "Smoke test"
+                            }
+                        },
+                        "meta": {
+                            "id_transaction": dataResponse['metadata']['id_transaction'],
+                            "status": 'ERROR' if errorCode < 0 else 'SUCCESS'
+                        }
                     }
-                },
-                "meta": {
-                    "id_transaction": dataResponse['metadata']['id_transaction'],
-                    "status": 'ERROR' if errorCode < 0 else 'SUCCESS'
                 }
-            })
+            )
 
         span.log_kv({'event': 'output', 'response': Resp['response']})
 
